<?php

namespace Drupal\monarch_symlink\Entity;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityStorageInterface;

/**
 * Defines the menu redirect entity class.
 *
 * @ContentEntityType(
 *   id = "menu_redirect",
 *   label = @Translation("Redirect"),
 *   label_collection = @Translation("Redirects"),
 *   label_singular = @Translation("redirect"),
 *   label_plural = @Translation("redirects"),
 *   label_count = @PluralTranslation(
 *     singular = "@count redirect",
 *     plural = "@count redirects"
 *   ),
 *   handlers = {
 *     "storage" = "\Drupal\menu_link_content\MenuLinkContentStorage",
 *     "storage_schema" = "Drupal\menu_link_content\MenuLinkContentStorageSchema",
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\monarch_symlink\MenuRedirectListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "access" = "Drupal\monarch_symlink\SymlinkAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\monarch_symlink\Form\MenuRedirectForm",
 *       "edit" = "Drupal\monarch_symlink\Form\MenuRedirectForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\monarch_symlink\Entity\MenuRedirectRouteProvider",
 *     }
 *   },
 *   base_table = "menu_redirect",
 *   revision_table = "menu_redirect_revision",
 *   admin_permission = "administer menu redirects",
 *   entity_keys = {
 *     "id" = "id",
 *     "revision" = "revision_id",
 *     "label" = "title",
 *     "langcode" = "langcode",
 *     "uuid" = "uuid",
 *     "bundle" = "bundle",
 *     "published" = "enabled",
 *   },
 *   revision_metadata_keys = {
 *     "revision_user" = "revision_user",
 *     "revision_created" = "revision_created",
 *     "revision_log_message" = "revision_log_message",
 *   },
 *   links = {
 *     "canonical" = "/menu-redirect/{menu_redirect}",
 *     "collection" = "/admin/structure/menu/menu-redirect",
 *     "add-form" = "/admin/structure/menu/menu-redirect/add",
 *     "edit-form" = "/admin/structure/menu/menu-redirect/{menu_redirect}/edit",
 *     "delete-form" = "/admin/structure/menu/menu-redirect/{menu_redirect}/delete",
 *   },
 *   constraints = {
 *     "MenuTreeHierarchy" = {}
 *   },
 * )
 */
class MenuRedirect extends SymlinkBase {

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage, array &$values) {
    $values += ['bundle' => 'menu_redirect'];
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginDefinition() {
    $definition = parent::getPluginDefinition();
    $definition['class'] = 'Drupal\monarch_symlink\Plugin\Menu\MenuRedirectMenuItem';
    $definition['form_class'] = '\Drupal\monarch_symlink\Form\MenuRedirectForm';
    $definition['provider'] = 'monarch_symlink';
    return $definition;
  }

    /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    /** @var \Drupal\Core\Field\BaseFieldDefinition[] $fields */
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['title']->setLabel(t('Redirect Title'));
    $fields['link']->setLabel(t('Redirect Target'));
    $fields['link']->setDescription(t('The location this redirect points to.'));

    $fields['path']->setLabel(t('Redirect Path'));
    $fields['path']->setDescription(t('The path for this redirect.'));

    return $fields;
  }

}
