<?php

namespace Drupal\monarch_symlink\Entity;

use Drupal\link\LinkItemInterface;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\menu_link_content\Entity\MenuLinkContent;

/**
 * Defines a base class for symlink entities.
 */
class SymlinkBase extends MenuLinkContent implements SymlinkInterface {

  /**
   * {@inheritdoc}
   */
  public function getTargetUrlObject() {
    return $this->link->first()->getUrl();
  }

  /**
   * {@inheritdoc}
   */
  public function getUrlObject() {
    return $this->toUrl();
  }

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    /** @var \Drupal\Core\Field\BaseFieldDefinition[] $fields */
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['title']->setLabel(t('Symlink Title'));

    // Symlinks only support internal paths
    $fields['link']->setLabel(t('Target'))
      ->setDescription(t('The location this symlink points to.'))
      ->setSettings([
        'link_type' => LinkItemInterface::LINK_INTERNAL,
        'title' => DRUPAL_DISABLED,
      ]);

    $fields['path'] = BaseFieldDefinition::create('path')
      ->setLabel(t('Symlink Path'))
      ->setDescription(t('The path for this symlink.'))
      ->setRequired(TRUE)
      ->setTranslatable(TRUE)
      ->setDisplayOptions('form', [
        'type' => 'path',
        'weight' => -3,
      ])
      ->setDisplayConfigurable('form', TRUE)
      ->setComputed(TRUE);

    return $fields;
  }

}
